@@ -18,7 +18,7 @@ from .charge import (
     ChargeFilters as ChargeFilters,
     ChargeFilter as ChargeFilter,
 )
-from .coupon import Coupon as Coupon, LimitationConfiguration as LimitationConfiguration
+from .coupon import Coupon as Coupon, CouponsList as CouponsList, LimitationConfiguration as LimitationConfiguration
 from .credit import CreditResponse as CreditResponse, CreditsResponse as CreditsResponse
 from .credit_note import (
     Item as Item,
@@ -54,6 +54,7 @@ from .invoice import (
     InvoiceMetadata as InvoiceMetadata,
     InvoiceMetadataList as InvoiceMetadataList,
     OneOffInvoice as OneOffInvoice,
+    InvoicePreview as InvoicePreview,
     InvoiceFeesList as InvoiceFeesList,
     InvoiceFee as InvoiceFee,
 )
@@ -90,4 +91,5 @@ from .usage_threshold import (
     UsageThresholdsResponse as UsageThresholdsResponse,
 )
 from .payment_request import PaymentRequest as PaymentRequest
+from .payment import Payment as Payment
 from .lifetime_usage import LifetimeUsageResponse as LifetimeUsageResponse
