@@ -3,10 +3,11 @@ from typing import List, Optional
 from lago_python_client.base_model import BaseModel
 
 from .billing_period import BillingPeriodsResponse
+from .coupon import CouponsList
 from .credit import CreditsResponse
-from .customer import CustomerResponse
+from .customer import Customer, CustomerResponse
 from .fee import FeesResponse
-from .subscription import SubscriptionsResponse
+from .subscription import Subscriptions, SubscriptionsResponse
 from .error_detail import ErrorDetailsResponse
 from ..base_model import BaseResponseModel
 from .usage_threshold import UsageThreshold
@@ -52,6 +53,15 @@ class OneOffInvoice(BaseModel):
     error_details: Optional[ErrorDetailsResponse]
 
 
+class InvoicePreview(BaseModel):
+    plan_code: Optional[str]
+    billing_time: Optional[str]
+    subscription_at: Optional[str]
+    coupons: Optional[CouponsList]
+    customer: Optional[Customer]
+    subscriptions: Optional[Subscriptions]
+
+
 class InvoiceAppliedTax(BaseResponseModel):
     lago_id: Optional[str]
     lago_invoice_id: Optional[str]
@@ -115,6 +125,7 @@ class InvoiceResponse(BaseResponseModel):
     sub_total_excluding_taxes_amount_cents: int
     sub_total_including_taxes_amount_cents: int
     total_amount_cents: int
+    total_due_amount_cents: int
     prepaid_credit_amount_cents: int
 
     file_url: Optional[str]
